import Button from '~/components/items/button'
import type { Route } from './+types/home'
import homeBanner from '~/images/home-banner.png'
import starHome from '~/images/star-home.svg'
import starYellow from '~/images/star-yellow.svg'
import handDrawArrow from '~/images/hand-draw-arrow.png'
import { NavLink } from 'react-router'
import banner02 from '~/images/banner-02.jpg'
import AppCarousel from '~/components/templates/app-carousel'
import GridItemImg01 from '~/components/icons/grid-item-img-01'
import GridItemImg02 from '~/components/icons/grid-item-img-02'
import GridItemImg03 from '~/components/icons/grid-item-img-03'
import { cloneElement } from 'react'
import bgOpacity from '~/images/bg-opacity.png'
import AccordionTemplate from '~/components/items/accordion'

export function meta({}: Route.MetaArgs) {
  return [
    { title: 'New React Router App' },
    { name: 'description', content: 'Welcome to React Router!' }
  ]
}

export default function Home() {
  const gridItems = [
    {
      image: <GridItemImg01 />,
      badge: '🔍 Aracınız İçin Doğru Parçayı Kullanın!',
      heading: 'Parça Sorgulama',
      description:
        'Orijinal parçalarla işinizi güvenle büyütün. Benim Ustam uygulamasıyla yedek parçaların orijinalliğini kolayca sorgulayabilir, güvenilir ve doğru parçaları kullanarak müşteri memnuniyetinizi artırabilirsiniz.'
    },
    {
      image: <GridItemImg02 />,
      badge: '💰 Sadakat Kazandırır!',
      heading: 'Puan Kazanma',
      description:
        'Benim Ustam’a üye olarak yaptığınız her orijinal parça alışverişinde puan kazanın. Biriktirdiğiniz puanlarla birbirinden değerli hediyelere sahip olun. İşinizi büyütürken kazancınızı artırın!'
    },
    {
      image: <GridItemImg03 />,
      badge: '🎉 Kazandığınız Puanları Hediyeye Dönüştürün!',
      heading: 'Hedİye Sitesİ',
      description:
        'Benim Ustam’da biriktirdiğiniz puanlarla ihtiyacınıza uygun birçok hediyeden yararlanabilirsiniz. Ustalara özel avantajları kaçırmayın, puanlarınızı en iyi şekilde değerlendirin.'
    }
  ]

  return (
    <div className="space-y-8 sm:space-y-36 pb-10">
      <img src={homeBanner} alt="" className="hidden sm:block absolute -right-48 lg:-right-34 xl:right-0 top-0 z-0 lg:opacity-100 opacity-70" />
      <div className="container mx-auto px-4 bg-transparent relative">
        <img
          className="hidden sm:inline-block my-12 relative xl:-left-12"
          src={starHome}
          width={18}
          height={18}
          alt=""
        />
        <div className="sm:max-w-[540px] space-y-5 sm:bg-transparent bg-secondary/10 sm:py-0 p-5 rounded-2xl">
          <h1 className="text-4xl sm:text-6xl xl:text-7xl font-bold sm:mb-10">
            Parça Bizden <br /> <span className="text-secondary">Ustalık Sizden</span>
          </h1>
          <p className="xl:text-lg text-gray font-medium sm:mb-10">
            Tamirhane ustalarına özel sadakat programı ile puan kazanın, hediyelerle işinizi
            büyütün!
          </p>
          <NavLink to="/auth/signup">
            <Button variant="secondary" className="py-4">
              Üye Ol ve Kazanmaya Başla
            </Button>
          </NavLink>
          <div className="mt-10 sm:pl-12 flex items-end">
            <img className="hidden sm:inline-block mb-4" src={handDrawArrow} alt="" />
            <div className="flex">
              {[...Array(3)].map((_, i) => (
                <div
                  key={i}
                  className="size-16 overflow-hidden rounded-full border-2 border-white bg-black/20 -mx-2"
                />
              ))}
            </div>
            <div className="ml-5">
              <span className="text-4xl font-medium">140K +</span> <br />
              <span className="text-xl text-gray font-medium">Mutlu Usta!</span>
            </div>
          </div>
          <div className="pl-40 sm:pl-36 space-y-2">
            <div className="text-2xl font-medium">4.8/5</div>
            <div className="flex">
              {[...Array(5)].map((_, i) => (
                <img src={starYellow} key={i} alt="" />
              ))}
            </div>
          </div>
        </div>
      </div>
      <div className="container mx-auto px-4">
        <div className="rounded-2xl overflow-hidden relative">
          <img src={banner02} alt="" className="w-full hidden sm:inline-block" />
          <div className="sm:bg-transparent bg-primary p-4 sm:absolute sm:right-8 xl:right-18 sm:top-8 xl:top-1/2 xl:-translate-y-1/2 bottom-0 text-end sm:max-w-[400px] lg:max-w-[600px] space-y-5 text-white">
            <h2 className="text-2xl lg:text-5xl font-medium">
              📢 Orijinal parça kullanın, işinizi büyütün, ödülleri kaçırmayın!
            </h2>

            <h3>
              Benim Ustam’a üye olarak sadakat programının <br /> sunduğu tüm avantajlardan
              faydalanabilirsiniz.
            </h3>

            <h4 className="font-medium flex gap-2 items-center justify-end">
              <svg
                width="24"
                height="24"
                viewBox="0 0 24 24"
                fill="none"
                xmlns="http://www.w3.org/2000/svg"
                className='lg:inline hidden'
              >
                <path
                  d="M13 2L4.09344 12.6879C3.74463 13.1064 3.57023 13.3157 3.56756 13.4925C3.56524 13.6461 3.63372 13.7923 3.75324 13.8889C3.89073 14 4.16316 14 4.70802 14H12L11 22L19.9065 11.3121C20.2553 10.8936 20.4297 10.6843 20.4324 10.5075C20.4347 10.3539 20.3663 10.2077 20.2467 10.1111C20.1092 10 19.8368 10 19.292 10H12L13 2Z"
                  stroke="white"
                  stroke-width="2"
                  stroke-linecap="round"
                  stroke-linejoin="round"
                />
              </svg>{' '}
              Ne Kadar Çok Kullanırsanız, O Kadar Çok Kazanırsınız!
            </h4>
            <NavLink to="/auth/signup">
              <Button variant="tertiary" className="py-4 ml-auto">
                Hemen Üye Ol
              </Button>
            </NavLink>
          </div>
        </div>
      </div>
      <div className="container mx-auto px-4">
        <AppCarousel />
      </div>
      <div className="container mx-auto px-4 space-y-6">
        <h3 className="font-semibold text-2xl lg:text-4xl xl:text-5xl">🔧 Benim Ustam ile Kazanmanın Yeni Yolu!</h3>
        <p className="text-gray xl:text-lg">
          Benim Ustam, tamirhane ustalarına özel geliştirilen bir sadakat programıdır. Orijinal
          parça sorgulama, puan kazanma ve ödüllerle avantaj sağlayan bu sistem sayesinde işinizi
          büyütürken kazancınızı artırabilirsiniz.
        </p>
        <div className="grid grid-cols-1 lg:grid-cols-3 rounded-2xl border border-[#EDEDED] overflow-hidden">
          {gridItems.map((item, i) => (
            <NavLink
              to="/"
              key={i}
              className="border-r last:border-0 border-[#EDEDED] group hover:text-white"
            >
              <div className="bg-[#F5F5F5] group-hover:bg-primary px-4 py-3 xl:px-8 xl:py-6 h-full relative">
                <img
                  src={bgOpacity}
                  alt=""
                  className="absolute z-0 bottom-0 -top-8 -right-10 opacity-0 group-hover:opacity-100"
                />
                <div className="h-[180px] xl:h-[230px] flex items-center justify-center relative bg-primary group-hover:bg-white rounded-2xl mb-6 transition-all duration-300">
                  {cloneElement(item.image, {
                    className: 'fill-white group-hover:fill-primary transition-all duration-300 '
                  })}
                </div>
                <span className="bg-[#1E407A0D] group-hover:bg-white/20 rounded-full px-1 py-1 xl:px-3 xl:py-2 text-xs font-medium">
                  {item.badge}
                </span>
                <h3 className="text-xl xl:text-2xl font-bold mt-3 mb-5 uppercase">{item.heading}</h3>
                <p className="xl:text-base text-sm font-medium text-gray group-hover:text-white">{item.description}</p>
              </div>
            </NavLink>
          ))}
        </div>
      </div>
      <div className="py-20 mx-4 bg-[#F6F7F9] rounded-2xl">
        <div className="container mx-auto px-4 space-y-4 sm:space-y-10">
          <div className="text-center space-y-4 sm:space-y-8 max-w-[680px] mx-auto">
            <span className="text-secondary bg-secondary/5 px-5 pt-1 pb-2 rounded-full leading-none text-xs inline-block">
              Sıkça Sorulan Sorular
            </span>
            <h3 className="font-medium text-2xl sm:text-5xl text-navy">Aklınıza Takılanlar mı Var?</h3>
            <p className="text-gray xl:text-lg">
              Benim Ustam’la ilgili merak ettiğiniz tüm detayları Sık Sorulan Sorular (SSS)
              bölümünde bulabilirsiniz.
            </p>
          </div>
          <div className="grid grid-cols-1 sm:grid-cols-2 gap-4">
            <AccordionTemplate />
          </div>
        </div>
      </div>
    </div>
  )
}
